@@ -33,7 +33,6 @@
  *
  *  Los valores por defecto son :
  *  \f[ U=1.0 \f]
- *  \f[ \sigma=1.0 \f]
  *  \f[ func(x)=tanh\left(\frac{x}{2}\right) \f]
  *  \param[in] Nel Es el número de entradas de la neurona.
  *  \return Un puntero al vector de tipo PdsNeuron.
@@ -41,58 +40,27 @@
  */
 PdsNeuron *pds_neuron_new(PdsSnNatural Nel)
 {
-	PdsNeuron *Neuron=NULL;
-	PdsSnNatural i;
-
-	if(Nel<=0)		return NULL;
-	
-	Neuron=(PdsNeuron *)calloc(1,sizeof(PdsNeuron));
-	if(Neuron==NULL)	return NULL;
-
-	Neuron->Nel=Nel;
-	Neuron->X=(PdsSnReal **)calloc(Neuron->Nel,sizeof(PdsSnReal*));
-	if(Neuron->X==NULL) 
-	{
-		free(Neuron);
-		return NULL;
-	}
-	for(i=0;i<Neuron->Nel;i++)	Neuron->X[i]=NULL;
-
-	Neuron->W=(PdsSnReal *)calloc(Neuron->Nel,sizeof(PdsSnReal));
-	if(Neuron->W==NULL) 
-	{
-		free(Neuron);
-		return NULL;
-	}
-
-	for(i=0;i<Neuron->Nel;i++)	Neuron->W[i]=0.0;
-	
-	Neuron->U=1.0;
-	Neuron->Sigma=1.0;
-	Neuron->Theta=0.0;
-    Neuron->func=pds_func;
-    Neuron->dfunc=pds_dfunc;
-
-	Neuron->F=0.0;
-	Neuron->Y[0]=0.0;
-	Neuron->Y[1]=0.0;
+	PdsNeuron *Neuron=pds_neuron_new_with_params(  Nel,    // Number of inputs
+                                                   0.0,    // Init weight values
+                                                   1.0,    // Init U value
+                                                   pds_func,
+                                                   pds_dfunc);
 
 	return Neuron;
 }
 
-/** \fn PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,PdsSnReal Sigma,double (*func)(double),double (*dfunc)(double));
+/** \fn PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,double (*func)(double),double (*dfunc)(double));
  *  \brief Crea una neurona de tipo PdsNeuron de Nel entradas.
  *
  *  \param[in] Nel Es el número de entradas de la neurona.
  *  \param[in] W Peso inicial de todas las entradas
  *  \param[in] U Umbral de disparo.
- *  \param[in] Sigma Factor de escala de la función de activación.
  *  \param[in] func Función de activación.
  *  \param[in] dfunc Derivada de la función de activación.
  *  \return Un puntero al vector de tipo PdsNeuron.
  *  \ingroup PdsNeuronGroup
  */
-PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,PdsSnReal Sigma,double (*func)(double),double (*dfunc)(double))
+PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,double (*func)(double),double (*dfunc)(double))
 {
 	PdsNeuron *Neuron=NULL;
 	PdsSnNatural i;
@@ -121,12 +89,10 @@ PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,P
 	for(i=0;i<Neuron->Nel;i++)	Neuron->W[i]=W;
 	
 	Neuron->U=U;
-	Neuron->Sigma=Sigma;
 	Neuron->Theta=0.0;
     Neuron->func=func;
     Neuron->dfunc=dfunc;
 
-	Neuron->F=0.0;
 	Neuron->Y[0]=0.0;
 	Neuron->Y[1]=0.0;
 
@@ -222,6 +188,75 @@ int pds_neuron_init_weight_rand(PdsNeuron *Neuron, PdsSnReal min, PdsSnReal max)
 	return TRUE;
 }
 
+/** \fn int pds_neuron_init_u_and_weight_rand(PdsNeuron *Neuron, PdsSnReal min, PdsSnReal max)
+ *  \brief Inicia el vector de pesos y U de la Neurona con valores aleatorios
+ *  uniformemente distribuido entre min y max.
+ *  \param[in,out] Neuron La neurona a escribir.
+ *  \param[in] min El minimo valor encontrado en los pesos de la neurona.
+ *  \param[in] max El minimo valor encontrado en los pesos de la neurona.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_init_u_and_weight_rand(PdsNeuron *Neuron, PdsSnReal min, PdsSnReal max)
+{
+	PdsSnNatural i;
+    PdsSnReal m;
+
+	if(Neuron==NULL)	return FALSE;
+
+    srand(clock());
+	for(i=0;i<Neuron->Nel;i++)
+    {
+        m = min+(rand()*(max-min))/RAND_MAX;
+	    Neuron->W[i]=m;
+    }
+
+    Neuron->U = min+(rand()*(max-min))/RAND_MAX;
+	return TRUE;
+}
+
+
+/** \fn int pds_neuron_printf_weight(const PdsNeuron *Neuron)
+ *  \brief Imprime los valores de los pesos en la Neurona.
+ *  \param[in] Neuron La neurona en consulta.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_printf_weight(const PdsNeuron *Neuron)
+{
+	if(Neuron==NULL)	return FALSE;
+
+    for(int i=0;i<Neuron->Nel;i++)
+    {
+		printf("W[%d]:%f",i,Neuron->W[i]);
+        if(i==(Neuron->Nel-1))  printf("\n");
+        else                    printf("\t");
+	}
+
+	return TRUE;
+}
+
+
+/** \fn int pds_neuron_printf_u_and_weight(const PdsNeuron *Neuron)
+ *  \brief Imprime los valores de U y los pesos en la Neurona.
+ *  \param[in] Neuron La neurona en consulta.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_printf_u_and_weight(const PdsNeuron *Neuron)
+{
+	if(Neuron==NULL)	return FALSE;
+
+
+
+    for(int i=0;i<Neuron->Nel;i++)
+    {
+		printf("W[%d]:%f\t",i,Neuron->W[i]);
+	}
+
+    printf("U:%f\n",Neuron->U);
+	return TRUE;
+}
 
 /** \fn int pds_neuron_get_number_of_inputs(const PdsNeuron *Neuron,PdsSnNatural *Nelements)
  *  \brief Devuelve el número de entradas de la Neurona.
@@ -243,42 +278,6 @@ int pds_neuron_get_number_of_inputs(const PdsNeuron *Neuron,PdsSnNatural *Neleme
 }
 
 
-/** \fn int pds_neuron_get_sigma(const PdsNeuron *Neuron,PdsSnReal *Sigma)
- *  \brief Devuelve el valor de  sigma de la Neurona.
- *  \param[in] Neuron La neurona en consulta.
- *  \param[out] Sigma En donde se guardará el valor de sigma de la neurona.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_get_sigma(const PdsNeuron *Neuron,PdsSnReal *Sigma)
-{
-	*Sigma=0;
-
-	if(Neuron==NULL)	return FALSE;
-
-	*Sigma=Neuron->Sigma;
-
-	return TRUE;
-}
-
-
-/** \fn int pds_neuron_set_sigma(PdsNeuron *Neuron,PdsSnReal Sigma)
- *  \brief Coloca el valor de  sigma de la Neurona.
- *  \param[in,out] Neuron La neurona a escribir.
- *  \param[in] Sigma El valor de sigma de la neurona.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_set_sigma(PdsNeuron *Neuron,PdsSnReal Sigma)
-{
-
-	if(Neuron==NULL)	return FALSE;
-
-	Neuron->Sigma=Sigma;
-
-	return TRUE;
-}
-
 
 /** \fn int pds_neuron_get_u(const PdsNeuron *Neuron,PdsSnReal *U)
  *  \brief Devuelve el valor de  U de la Neurona.
@@ -386,6 +385,28 @@ int pds_neuron_get_output(const PdsNeuron *Neuron,PdsSnReal *m)
 
 
 
+/** \fn int pds_neuron_connect_input_with_nivector(PdsNeuron *Neuron,const PdsNIVector *NIVector)
+ *  \brief Conecta el valor de salida Y de las neuronas NIVector con la 
+ *  entrada X[id] de la neurona Neuron.
+ *  \param[in,out] Neuron La neurona a trabajar.
+ *  \param[in] NIVector Vector de neuronas de entrada que se conectará a la entrada X[id] de Neuron.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL, Neuron->Nel!=NInput->Nel). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_connect_input_with_nivector(PdsNeuron *Neuron,const PdsNIVector *NIVector)
+{
+	if(Neuron==NULL)		        return FALSE;
+	if(NIVector==NULL)		        return FALSE;
+	if(Neuron->Nel!=NIVector->Nel)  return FALSE;
+
+    for(PdsSnNatural i=0;i<Neuron->Nel;i++)
+    {
+	    Neuron->X[i]=NIVector->V[i]->Y;
+    }
+
+	return TRUE;
+}
+
 /** \fn int pds_neuron_connect_input_with_ninput(PdsNeuron *Neuron,PdsSnNatural id,PdsNInput *NInput)
  *  \brief Conecta el valor de salida Y de la neurona de entrada NInput con la 
  *  entrada X[id] de la neurona Neuron.
@@ -431,6 +452,8 @@ int pds_neuron_connect_input(PdsNeuron *Neuron,PdsSnNatural id,PdsNeuron *Neuron
 /** \fn int pds_neuron_evaluate_theta(PdsNeuron *Neuron)
  *  \brief Evalua la variable theta de la Neurona Neuron.
  *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f].
+ *
+ *  Valores de entrada apuntadas a NULL no son consideradas en la suma.
  *  \param[in,out] Neuron La neurona a evaluar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
@@ -456,73 +479,30 @@ int pds_neuron_evaluate_theta(PdsNeuron *Neuron)
 
 
 /** \fn int pds_neuron_evaluate_func(PdsNeuron *Neuron)
- *  \brief Evalua la funcion de activación de la Neurona Neuron.
- *  \f[ func\left(\frac{\theta}{\sigma}\right) \f]
+ *  \brief Actualiza el valor a la salida de la Neurona Neuron.
+ *  \f[ Y=func\left(\theta\right) \f]
+ *  Adicionalmente (Neuron->Y[1]=0)
+ *  \f[ e=0 \f]
  *  \param[in,out] Neuron La neurona a evaluar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
 int pds_neuron_evaluate_func(PdsNeuron *Neuron)
 {
-	PdsSnReal x;
-
 	if(Neuron==NULL)		return FALSE;
 
-	x=Neuron->Theta/Neuron->Sigma;
-
-	Neuron->F=Neuron->func(x);
-
-	return TRUE;
-}
-
-
-/** \fn int pds_neuron_evaluate(PdsNeuron *Neuron)
- *  \brief Evalua la Neurona Neuron.
- *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f]
- *  \f[ func\left(\frac{\theta}{\sigma}\right) \f]
- *  \param[in,out] Neuron La neurona a evaluar.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_evaluate(PdsNeuron *Neuron)
-{
-	int m;
-	if(Neuron==NULL)		return FALSE;
-
-	m=pds_neuron_evaluate_theta(Neuron);
-	if(m==FALSE)	return FALSE;
-	m=pds_neuron_evaluate_func(Neuron);
-	if(m==FALSE)	return FALSE;
-
-	return TRUE;
-}
-
-
-/** \fn int pds_neuron_update(PdsNeuron *Neuron)
- *  \brief Actualiza el valor a la salida de la Neurona Neuron.
- *  \f[ Y=func\left(\frac{\theta}{\sigma}\right) \f]
- *  Adicionalmente (Neuron->Y[1]=0)
- *  \f[ e=0 \f]
- *  \param[in,out] Neuron La neurona a trabajar.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_update(PdsNeuron *Neuron)
-{
-	if(Neuron==NULL)		return FALSE;
-
-	*(Neuron->Y)=Neuron->F;
+	*(Neuron->Y)=Neuron->func(Neuron->Theta);
 	Neuron->Y[1]=0.0;
-
 	return TRUE;
 }
 
 
+
 /** \fn int pds_neuron_iterate(PdsNeuron *Neuron)
  *  \brief Itera la Neurona Neuron.
  *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f]
- *  \f[ func\left(\frac{\theta}{\sigma}\right) \f]
- *  \f[ Y=func\left(\frac{\theta}{\sigma}\right) \f]
+ *  \f[ func\left(\theta\right) \f]
+ *  \f[ Y=func\left(\theta\right) \f]
  *  Adicionalmente (Neuron->Y[1]=0)
  *  \f[ e=0 \f]
  *  \param[in,out] Neuron La neurona a iterar.
@@ -538,16 +518,12 @@ int pds_neuron_iterate(PdsNeuron *Neuron)
 	m=pds_neuron_evaluate_theta(Neuron);
 	if(m==FALSE)	return FALSE;
 	m=pds_neuron_evaluate_func(Neuron);
-	if(m==FALSE)	return FALSE;
 
-	*(Neuron->Y)=Neuron->F;
-	Neuron->Y[1]=0.0;
-
-	return TRUE;
+	return m;
 }
 
 
-/** \fn int pds_neuron_evaluate_error(PdsNeuron *Neuron,PdsSnReal y)
+/** \fn int pds_neuron_evaluate_diff_error(PdsNeuron *Neuron,PdsSnReal y)
  *  \brief Compara el valor de salida \f$Y\f$ de la neurona, con "y", luego lo carga
  *  en la variable Y[1] de la neurona (Neuron->Y[1]=y-Neuron->Y[0]).
  *  \f[ e= y - Y\f]
@@ -556,7 +532,7 @@ int pds_neuron_iterate(PdsNeuron *Neuron)
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_evaluate_error(PdsNeuron *Neuron,PdsSnReal y)
+int pds_neuron_evaluate_diff_error(PdsNeuron *Neuron,PdsSnReal y)
 {
 
 	if(Neuron==NULL)		return FALSE;
@@ -567,27 +543,24 @@ int pds_neuron_evaluate_error(PdsNeuron *Neuron,PdsSnReal y)
 }
 
 
-/** \fn int pds_neuron_backpropagate_error(PdsNeuron *Neuron)
+/** \fn int pds_neuron_backpropagate_error(PdsNeuron *Neuron,PdsSnReal Alpha)
  *  \brief Propaga el error de la salida de la neurona hacia las neuronas conectadas
  *  a sus entradas. <br>
- *  <center>
- *  \image html backpropagation.png "Backpropagation"
- *  </center>
- *  <br>
- *  <center>
- *  \image html backpropagation2.png "Backpropagation"
- *  </center>
- *  <br>
  *  \f[ e = e_{\{Y\}} \f]
  *  \f[ e_i = e_{\{X[i]\}} \f]
- *  \f[ e_i \leftarrow e_i + \frac{func'\left(\frac{\theta}{\sigma}\right)}{\sigma}W[i]e\f]
+ *  \f[ e_i \leftarrow e_i + func'\left(\theta\right)W[i]e\f]
+ *  \image html backpropagation.png "Backpropagation"
+ *  <br>
+ *  \image html backpropagation2.png "Backpropagation"
+ *  <br>
  *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
  *  "func" es la función de activación da neurona Neuron.<br>
  *  \param[in,out] Neuron La neurona a retropropagar el error.
+ *  \param[in] Alpha Factor de aprendizaje de los errores.
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_backpropagate_error(PdsNeuron *Neuron)
+int pds_neuron_backpropagate_error(PdsNeuron *Neuron,PdsSnReal Alpha)
 {
 	PdsSnReal e,Df;
 	PdsSnNatural i;
@@ -595,7 +568,7 @@ int pds_neuron_backpropagate_error(PdsNeuron *Neuron)
 
 	if(Neuron==NULL)		return FALSE;
 
-	Df=Neuron->dfunc(Neuron->Theta/Neuron->Sigma)/Neuron->Sigma;
+	Df=Neuron->dfunc(Neuron->Theta);
 
 	e=Neuron->Y[1];
 	for(i=0;i<Neuron->Nel;i++)	
@@ -603,7 +576,7 @@ int pds_neuron_backpropagate_error(PdsNeuron *Neuron)
 		if(Neuron->X[i]!=NULL)
         {
             y1=(Neuron->X[i]+1);
-		    (*y1)=(*y1)+Neuron->W[i]*Df*e;
+		    (*y1)=(*y1)+Alpha*Neuron->W[i]*Df*e;
         }
 	}
 
@@ -614,7 +587,7 @@ int pds_neuron_backpropagate_error(PdsNeuron *Neuron)
 /** \fn int pds_neuron_update_weight(PdsNeuron *Neuron, PdsSnReal Alpha)
  *  \brief Actualiza los pesos W[i] de la neurona (using the Delta rule).
  *  \f[ e = r-Y\f]
- *  \f[ \triangle W[i]= \alpha \frac{func'\left(\frac{\theta}{\sigma}\right)}{\sigma} X[i] e\f]
+ *  \f[ \triangle W[i]= \alpha func'\left(\theta\right) X[i] e\f]
  *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
  *  "Y" salida de la neurona Neuron :Neuron->Y[0].<br>
  *  "func" es la función de activación da neurona Neuron.<br>
@@ -631,7 +604,7 @@ int pds_neuron_update_weight(PdsNeuron *Neuron, PdsSnReal Alpha)
 
 	if(Neuron==NULL)		return FALSE;
 
-	Df=Neuron->dfunc(Neuron->Theta/Neuron->Sigma)/Neuron->Sigma;
+	Df=Neuron->dfunc(Neuron->Theta);
 	e=Neuron->Y[1];
 
 	for(i=0;i<Neuron->Nel;i++)	
@@ -647,6 +620,44 @@ int pds_neuron_update_weight(PdsNeuron *Neuron, PdsSnReal Alpha)
 }
 
 
+/** \fn int pds_neuron_update_u_and_weight(PdsNeuron *Neuron, PdsSnReal Alpha)
+ *  \brief Actualiza los pesos W[i] de la neurona (using the Delta rule).
+ *  \f[ e = r-Y\f]
+ *  \f[ \triangle W[i]= \alpha func'\left(\theta\right) X[i] e\f]
+ *  \f[ \triangle U= -\alpha func'\left(\theta\right) e\f]
+ *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
+ *  "Y" salida de la neurona Neuron :Neuron->Y[0].<br>
+ *  "func" es la función de activación da neurona Neuron.<br>
+ *  "X" Vector con los valores de todas las entradas de la neurona.<br>
+ *  \param[in,out] Neuron La neurona a actualizar los pesos.
+ *  \param[in] Alpha Factor de aprendizaje de los pesos.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_update_u_and_weight(PdsNeuron *Neuron, PdsSnReal Alpha)
+{
+	PdsSnReal e,x,Df;
+	PdsSnNatural i;
+
+	if(Neuron==NULL)		return FALSE;
+
+	Df=Neuron->dfunc(Neuron->Theta);
+	e=Neuron->Y[1];
+
+    Neuron->U=Neuron->U-Alpha*e*Df;
+
+	for(i=0;i<Neuron->Nel;i++)	
+	{
+		if(Neuron->X[i]!=NULL)
+		{
+			x=(*(Neuron->X[i]));
+			Neuron->W[i]=Neuron->W[i]+Alpha*e*Df*x;
+		}
+	}
+
+	return TRUE;
+}
+
 /** \fn int pds_neuron_get_xtx(PdsNeuron *Neuron,PdsSnReal *XtX)
  *  \brief Devuelve la suma cuadrática de los valores de entrada de la neurona.
  *  \f[ X^T X=\sum^{Nel-1}_{i=0} X[i]^2 \f].
@@ -669,10 +680,11 @@ int pds_neuron_get_xtx(PdsNeuron *Neuron,PdsSnReal *XtX)
 }
 
 
-/** \fn int pds_neuron_update_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha)
+/** \fn int pds_neuron_update_u_and_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha)
  *  \brief Actualiza los pesos W[i] de la neurona (using the Delta rule).
  *  \f[ e = r-Y\f]
- *  \f[ \triangle W[i]= \alpha \frac{func'\left(\frac{\theta}{\sigma}\right)}{\sigma} \frac{X[i]}{X^TX} e \f]
+ *  \f[ \triangle W[i]= \alpha func'\left(\theta\right) \frac{X[i]}{X^TX+1} e \f]
+ *  \f[ \triangle U= -\alpha func'\left(\theta\right) \frac{1}{X^TX+1} e \f]
  *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
  *  "Y" salida de la neurona Neuron :Neuron->Y[0].<br>
  *  "func" es la función de activación da neurona Neuron.<br>
@@ -682,14 +694,14 @@ int pds_neuron_get_xtx(PdsNeuron *Neuron,PdsSnReal *XtX)
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_update_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha)
+int pds_neuron_update_u_and_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha)
 {
 	PdsSnReal e,x,Df,XtX;
 	PdsSnNatural i;
 
 	if(Neuron==NULL)		return FALSE;
 
-	Df=Neuron->dfunc(Neuron->Theta/Neuron->Sigma)/Neuron->Sigma;
+	Df=Neuron->dfunc(Neuron->Theta);
 	e=Neuron->Y[1];
 	
 	for(XtX=0,i=0;i<Neuron->Nel;i++)	
@@ -700,16 +712,16 @@ int pds_neuron_update_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha)
 		if((Neuron->X[i]!=NULL)&&(XtX>0))
 		{
 			x=(*(Neuron->X[i]));
-			Neuron->W[i]=Neuron->W[i]+Alpha*e*Df*x/XtX;
+			Neuron->W[i]=Neuron->W[i]+Alpha*e*Df*x/(XtX+1.0);
 		}
 	}
-
+    Neuron->U=Neuron->U-Alpha*e*Df/(XtX+1.0);
 	return TRUE;
 }
 
 
 /** \fn int pds_neuron_fprintf(const PdsNeuron *Neuron, FILE *fd)
- *  \brief Guarda en un archivo de texto los pesos {W[i]} y  {U, Sigma}.
+ *  \brief Guarda en un archivo de texto los pesos {W[i]} y  {U}.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
  *  \param[in] Neuron La neurona a leer.
  *  \param[in,out] fd Manejador del fichero a escribir.
@@ -727,19 +739,19 @@ int pds_neuron_fprintf(const PdsNeuron *Neuron, FILE *fd)
 
 	for(i=0;i<Neuron->Nel;i++)	
 	{
-		if(i!=(Neuron->Nel-1))	tmp=fprintf(fd,"%e\t",Neuron->W[i]);
-		else                    tmp=fprintf(fd,"%e\n",Neuron->W[i]);
+		tmp=fprintf(fd,"%e\t",Neuron->W[i]);
+        if(tmp==0)	return FALSE;
 	}
 
-	tmp=fprintf(fd,"%e\t",Neuron->U);
-	tmp=fprintf(fd,"%e\n",Neuron->Sigma);
+	tmp=fprintf(fd,"%e\n",Neuron->U);
+	if(tmp==0)	return FALSE;
 
 	return TRUE;
 }
 
 
 /** \fn int pds_neuron_fscanf(PdsNeuron *Neuron, FILE *fd)
- *  \brief Lee de un archivo de texto los pesos {W[i]} y  {U, Sigma}.
+ *  \brief Lee de un archivo de texto los pesos {W[i]} y  {U}.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
  *  \param[out] Neuron La neurona a escribir.
  *  \param[in,out] fd Manejador del fichero a leer.
@@ -764,15 +776,12 @@ int pds_neuron_fscanf(PdsNeuron *Neuron, FILE *fd)
 	tmp=fscanf(fd,"%e",&(Neuron->U));
 	if(tmp==0)	return FALSE;
 
-	tmp=fscanf(fd,"%e",&(Neuron->Sigma));
-	if(tmp==0)	return FALSE;
-
 	return TRUE;
 }
 
 
 /** \fn int pds_neuron_fwrite(const PdsNeuron *Neuron, FILE *fd)
- *  \brief Guarda en un archivo binario los pesos W[i], el valor de U y Sigma.
+ *  \brief Guarda en un archivo binario los pesos W[i], el valor de U.
  *  \param[in] Neuron La neurona a leer.
  *  \param[in,out] fd Manejador del fichero binario a escribir.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL o fd==NULL). 
@@ -796,15 +805,12 @@ int pds_neuron_fwrite(const PdsNeuron *Neuron, FILE *fd)
 	tmp=fwrite(&(Neuron->U),sizeof(Neuron->U),1,fd);
 	if(tmp!=1)	return	FALSE;
 
-	tmp=fwrite(&(Neuron->Sigma),sizeof(Neuron->Sigma),1,fd);
-	if(tmp!=1)	return	FALSE;
-
 	return TRUE;
 }
 
 
 /** \fn int pds_neuron_fread(PdsNeuron *Neuron, FILE *fd)
- *  \brief Lee de un archivo binario los pesos W[i], el valor de U y Sigma.
+ *  \brief Lee de un archivo binario los pesos W[i], el valor de U.
  *  \param[out] Neuron La neurona a escribir.
  *  \param[in,out] fd Manejador del fichero binario a leer.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL o fd==NULL). 
@@ -828,9 +834,6 @@ int pds_neuron_fread(PdsNeuron *Neuron, FILE *fd)
 	tmp=fread(&(Neuron->U),sizeof(Neuron->U),1,fd);
 	if(tmp!=1)	return FALSE;
 
-	tmp=fread(&(Neuron->Sigma),sizeof(Neuron->Sigma),1,fd);
-	if(tmp!=1)	return FALSE;
-
 	return TRUE;
 }
 
