@@ -40,6 +40,7 @@ extern "C" {
 #include <stdio.h>
 #include <stdlib.h>
 #include <pds/pdsninput.h>
+#include <pds/pdsnivector.h>
 #include <pds/pdssnglobal.h>
 
 #ifndef TRUE
@@ -87,9 +88,6 @@ typedef struct
 	/*! Valor de umbral. */
 	PdsSnReal U;
 
-	/*! Valor de Sigma. */
-	PdsSnReal Sigma;
-
 	/*! Valor de ponderacion. */
 	PdsSnReal Theta;
 
@@ -99,8 +97,6 @@ typedef struct
 	/*! Derivada de la función de activación.*/
     double (*dfunc)(double);
 
-	/*! Valor de activación. */
-	PdsSnReal F;
 	/*! Valor de salida *Y, y un espacio extra Y[1]. */
 	PdsSnReal Y[2];
 }PdsNeuron;
@@ -124,7 +120,6 @@ typedef struct
  *
  *  Los valores por defecto son :
  *  \f[ U=1.0 \f]
- *  \f[ \sigma=1.0 \f]
  *  \f[ func(x)=tanh\left(\frac{x}{2}\right) \f]
  *  \param[in] Nel Es el número de entradas de la neurona.
  *  \return Un puntero al vector de tipo PdsNeuron.
@@ -133,24 +128,23 @@ typedef struct
 PdsNeuron *pds_neuron_new(PdsSnNatural Nel);
 
 
-/** \fn PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,PdsSnReal Sigma,double (*func)(double),double (*dfunc)(double));
+/** \fn PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,double (*func)(double),double (*dfunc)(double));
  *  \brief Crea una neurona de tipo PdsNeuron de Nel entradas.
  *
  *  \param[in] Nel Es el número de entradas de la neurona.
  *  \param[in] W Peso inicial de todas las entradas
  *  \param[in] U Umbral de disparo.
- *  \param[in] Sigma Factor de escala de la función de activación.
  *  \param[in] func Función de activación.
  *  \param[in] dfunc Derivada de la función de activación.
  *  \return Un puntero al vector de tipo PdsNeuron.
  *  \ingroup PdsNeuronGroup
  */
-PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,PdsSnReal Sigma,double (*func)(double),double (*dfunc)(double));
+PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,double (*func)(double),double (*dfunc)(double));
 
 //@}
 
-/** @name pds_neuron_<input_methods>
- *  Obteniendo datos.
+/** @name pds_neuron_<connect_input_methods>
+ *  Conectando datos.
  *
  * @{
  */
@@ -168,6 +162,40 @@ PdsNeuron *pds_neuron_new_with_params(PdsSnNatural Nel,PdsSnReal W,PdsSnReal U,P
 int pds_neuron_connect_input(PdsNeuron *Neuron,PdsSnNatural id,PdsNeuron *NeuronX);
 
 
+
+
+/** \fn int pds_neuron_connect_input_with_ninput(PdsNeuron *Neuron,PdsSnNatural id,PdsNInput *NInput)
+ *  \brief Conecta el valor de salida Y de la neurona de entrada NInput con la 
+ *  entrada X[id] de la neurona Neuron.
+ *  \param[in,out] Neuron La neurona a trabajar.
+ *  \param[in] id La posición a conectar, id tiene que ser menor que Nel.
+ *  \param[in] NInput La neurona de entrada que se conectará a la entrada X[id] de Neuron.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_connect_input_with_ninput(PdsNeuron *Neuron,PdsSnNatural id,PdsNInput *NInput);
+
+
+
+/** \fn int pds_neuron_connect_input_with_nivector(PdsNeuron *Neuron,const PdsNIVector *NIVector)
+ *  \brief Conecta el valor de salida Y de las neuronas NIVector con la 
+ *  entrada X[id] de la neurona Neuron.
+ *  \param[in,out] Neuron La neurona a trabajar.
+ *  \param[in] NIVector Vector de neuronas de entrada que se conectará a la entrada X[id] de Neuron.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL, Neuron->Nel!=NInput->Nel). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_connect_input_with_nivector(PdsNeuron *Neuron,const PdsNIVector *NIVector);
+
+
+//@}
+
+/** @name pds_neuron_<get_set_input_methods>
+ *  Trabajando con las entradas
+ *
+ * @{
+ */
+
 /** \fn const PdsSnReal *pds_neuron_get_dendrite(const PdsNeuron *Neuron,PdsSnNatural id)
  *  \brief Devuelve la dirección de la entrada X[id] de la Neurona.
  *  \param[in] Neuron La neurona en consulta.
@@ -189,19 +217,6 @@ const PdsSnReal *pds_neuron_get_dendrite(const PdsNeuron *Neuron,PdsSnNatural id
 int pds_neuron_get_input(const PdsNeuron *Neuron,PdsSnNatural id,PdsSnReal *m);
 
 
-
-/** \fn int pds_neuron_connect_input_with_ninput(PdsNeuron *Neuron,PdsSnNatural id,PdsNInput *NInput)
- *  \brief Conecta el valor de salida Y de la neurona de entrada NInput con la 
- *  entrada X[id] de la neurona Neuron.
- *  \param[in,out] Neuron La neurona a trabajar.
- *  \param[in] id La posición a conectar, id tiene que ser menor que Nel.
- *  \param[in] NInput La neurona de entrada que se conectará a la entrada X[id] de Neuron.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_connect_input_with_ninput(PdsNeuron *Neuron,PdsSnNatural id,PdsNInput *NInput);
-
-
 //@}
 
 /** @name pds_neuron_<weight_methods>
@@ -222,11 +237,6 @@ int pds_neuron_connect_input_with_ninput(PdsNeuron *Neuron,PdsSnNatural id,PdsNI
  */
 int pds_neuron_get_weight(const PdsNeuron *Neuron, PdsSnNatural x, PdsSnReal *m);
 
-/*! \def PDS_NSETW(Neuron,i,m)
- *  Es equivalente a Neuron->W[i]=m.
- *  \ingroup PdsNeuronGroup
-*/
-#define PDS_NSETW(Neuron,i,m) pds_neuron_set_weight(Neuron,i,m)
 
 /** \fn int pds_neuron_set_weight(PdsNeuron *Neuron, PdsSnNatural x, PdsSnReal m)
  *  \brief Escribe el valor m en la posición (x) del vector de pesos de la Neurona.
@@ -240,7 +250,6 @@ int pds_neuron_get_weight(const PdsNeuron *Neuron, PdsSnNatural x, PdsSnReal *m)
  */
 int pds_neuron_set_weight(PdsNeuron *Neuron, PdsSnNatural x, PdsSnReal m);
 
-
 /** \fn int pds_neuron_init_weight(PdsNeuron *Neuron, PdsSnReal m)
  *  \brief Inicia el vector de pesos de la Neurona.
  *  \param[in,out] Neuron La neurona a escribir.
@@ -262,6 +271,33 @@ int pds_neuron_init_weight(PdsNeuron *Neuron, PdsSnReal m);
  */
 int pds_neuron_init_weight_rand(PdsNeuron *Neuron, PdsSnReal min, PdsSnReal max);
 
+/** \fn int pds_neuron_init_u_and_weight_rand(PdsNeuron *Neuron, PdsSnReal min, PdsSnReal max)
+ *  \brief Inicia el vector de pesos y U de la Neurona con valores aleatorios
+ *  uniformemente distribuido entre min y max.
+ *  \param[in,out] Neuron La neurona a escribir.
+ *  \param[in] min El minimo valor encontrado en los pesos de la neurona.
+ *  \param[in] max El minimo valor encontrado en los pesos de la neurona.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_init_u_and_weight_rand(PdsNeuron *Neuron, PdsSnReal min, PdsSnReal max);
+
+/** \fn int pds_neuron_printf_weight(const PdsNeuron *Neuron)
+ *  \brief Imprime los valores de los pesos en la Neurona.
+ *  \param[in] Neuron La neurona en consulta.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_printf_weight(const PdsNeuron *Neuron);
+
+
+/** \fn int pds_neuron_printf_u_and_weight(const PdsNeuron *Neuron)
+ *  \brief Imprime los valores de U y los pesos en la Neurona.
+ *  \param[in] Neuron La neurona en consulta.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_printf_u_and_weight(const PdsNeuron *Neuron);
 
 /** \fn int pds_neuron_get_number_of_inputs(const PdsNeuron *Neuron,PdsSnNatural *Nelements)
  *  \brief Devuelve el número de entradas de la Neurona.
@@ -274,22 +310,12 @@ int pds_neuron_get_number_of_inputs(const PdsNeuron *Neuron,PdsSnNatural *Neleme
 
 //@}
 
-/** @name pds_neuron_<theta_methods>
- *  Obteniendo datos.
+/** @name pds_neuron_<u_methods>
+ *  Trabajando con el valor U
  *
  * @{
  */
 
-/** \fn int pds_neuron_evaluate_theta(PdsNeuron *Neuron)
- *  \brief Evalua la variable theta de la Neurona Neuron.
- *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f].
- *  \param[in,out] Neuron La neurona a evaluar.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_evaluate_theta(PdsNeuron *Neuron);
-
-
 
 /** \fn int pds_neuron_get_u(const PdsNeuron *Neuron,PdsSnReal *U)
  *  \brief Devuelve el valor de  U de la Neurona.
@@ -310,80 +336,46 @@ int pds_neuron_get_u(const PdsNeuron *Neuron,PdsSnReal *U);
  */
 int pds_neuron_set_u(PdsNeuron *Neuron,PdsSnReal U);
 
-//@}
 
 
-/** @name pds_neuron_<func_methods>
- *  Trabajando con la función de activación.
- *
- * @{
- */
-
-/** \fn int pds_neuron_evaluate_func(PdsNeuron *Neuron)
- *  \brief Evalua la funcion de activación de la Neurona Neuron.
- *  \f[ func\left(\frac{\theta}{\sigma}\right) \f]
- *  \param[in,out] Neuron La neurona a evaluar.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_evaluate_func(PdsNeuron *Neuron);
-
-/** \fn int pds_neuron_get_sigma(const PdsNeuron *Neuron,PdsSnReal *Sigma)
- *  \brief Devuelve el valor de  sigma de la Neurona.
- *  \param[in] Neuron La neurona en consulta.
- *  \param[out] Sigma En donde se guardará el valor de sigma de la neurona.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_get_sigma(const PdsNeuron *Neuron,PdsSnReal *Sigma);
-
-
-/** \fn int pds_neuron_set_sigma(PdsNeuron *Neuron,PdsSnReal Sigma)
- *  \brief Coloca el valor de  sigma de la Neurona.
- *  \param[in,out] Neuron La neurona a escribir.
- *  \param[in] Sigma El valor de sigma de la neurona.
- *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
- *  \ingroup PdsNeuronGroup
- */
-int pds_neuron_set_sigma(PdsNeuron *Neuron,PdsSnReal Sigma);
-
 //@}
 
-
 /** @name pds_neuron_<evaluate>
  *  Trabajando con la 
  *
  * @{
  */
 
-/** \fn int pds_neuron_evaluate(PdsNeuron *Neuron)
- *  \brief Evalua la Neurona Neuron.
- *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f]
- *  \f[ func\left(\frac{\theta}{\sigma}\right) \f]
+
+/** \fn int pds_neuron_evaluate_theta(PdsNeuron *Neuron)
+ *  \brief Evalua la variable theta de la Neurona Neuron.
+ *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f].
+ *
+ *  Valores de entrada apuntadas a NULL no son consideradas en la suma.
  *  \param[in,out] Neuron La neurona a evaluar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_evaluate(PdsNeuron *Neuron);
+int pds_neuron_evaluate_theta(PdsNeuron *Neuron);
 
 
-/** \fn int pds_neuron_update(PdsNeuron *Neuron)
+/** \fn int pds_neuron_evaluate_func(PdsNeuron *Neuron)
  *  \brief Actualiza el valor a la salida de la Neurona Neuron.
- *  \f[ Y=func\left(\frac{\theta}{\sigma}\right) \f]
+ *  \f[ Y=func\left(\theta\right) \f]
  *  Adicionalmente (Neuron->Y[1]=0)
- *  \f[ e=0 \f].
- *  \param[in,out] Neuron La neurona a trabajar.
+ *  \f[ e=0 \f]
+ *  \param[in,out] Neuron La neurona a evaluar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_update(PdsNeuron *Neuron);
+int pds_neuron_evaluate_func(PdsNeuron *Neuron);
 
 
 /** \fn int pds_neuron_iterate(PdsNeuron *Neuron)
  *  \brief Itera la Neurona Neuron.
  *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f]
- *  \f[ func\left(\frac{\theta}{\sigma}\right) \f]
- *  \f[ Y=func\left(\frac{\theta}{\sigma}\right) \f]
+ *  \f[ func\left(\theta\right) \f]
+ *  \f[ Y=func\left(\theta\right) \f]
  *  Adicionalmente (Neuron->Y[1]=0)
  *  \f[ e=0 \f]
  *  \param[in,out] Neuron La neurona a iterar.
@@ -431,7 +423,7 @@ int pds_neuron_get_output(const PdsNeuron *Neuron,PdsSnReal *m);
 
 
 
-/** \fn int pds_neuron_evaluate_error(PdsNeuron *Neuron,PdsSnReal y)
+/** \fn int pds_neuron_evaluate_diff_error(PdsNeuron *Neuron,PdsSnReal y)
  *  \brief Compara el valor de salida \f$Y\f$ de la neurona, con "y", luego lo carga
  *  en la variable Y[1] de la neurona (Neuron->Y[1]=y-Neuron->Y[0]).
  *  \f[ e= y - Y\f]
@@ -440,30 +432,27 @@ int pds_neuron_get_output(const PdsNeuron *Neuron,PdsSnReal *m);
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_evaluate_error(PdsNeuron *Neuron,PdsSnReal y);
+int pds_neuron_evaluate_diff_error(PdsNeuron *Neuron,PdsSnReal y);
 
 
-/** \fn int pds_neuron_backpropagate_error(PdsNeuron *Neuron)
+/** \fn int pds_neuron_backpropagate_error(PdsNeuron *Neuron,PdsSnReal Alpha)
  *  \brief Propaga el error de la salida de la neurona hacia las neuronas conectadas
  *  a sus entradas. <br>
- *  <center>
- *  \image html backpropagation.png "Backpropagation"
- *  </center>
- *  <br>
- *  <center>
- *  \image html backpropagation2.png "Backpropagation"
- *  </center>
- *  <br>
  *  \f[ e = e_{\{Y\}} \f]
  *  \f[ e_i = e_{\{X[i]\}} \f]
- *  \f[ e_i \leftarrow e_i + \frac{func'\left(\frac{\theta}{\sigma}\right)}{\sigma}W[i]e\f]
+ *  \f[ e_i \leftarrow e_i + func'\left(\theta\right)W[i]e\f]
+ *  \image html backpropagation.png "Backpropagation"
+ *  <br>
+ *  \image html backpropagation2.png "Backpropagation"
+ *  <br>
  *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
  *  "func" es la función de activación da neurona Neuron.<br>
  *  \param[in,out] Neuron La neurona a retropropagar el error.
+ *  \param[in] Alpha Factor de aprendizaje de los errores.
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_backpropagate_error(PdsNeuron *Neuron);
+int pds_neuron_backpropagate_error(PdsNeuron *Neuron,PdsSnReal Alpha);
 
 
 
@@ -479,7 +468,7 @@ int pds_neuron_backpropagate_error(PdsNeuron *Neuron);
 /** \fn int pds_neuron_update_weight(PdsNeuron *Neuron, PdsSnReal Alpha)
  *  \brief Actualiza los pesos W[i] de la neurona (using the Delta rule).
  *  \f[ e = r-Y\f]
- *  \f[ \triangle W[i]= \alpha \frac{func'\left(\frac{\theta}{\sigma}\right)}{\sigma} X[i] e\f]
+ *  \f[ \triangle W[i]= \alpha func'\left(\theta\right) X[i] e\f]
  *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
  *  "Y" salida de la neurona Neuron :Neuron->Y[0].<br>
  *  "func" es la función de activación da neurona Neuron.<br>
@@ -492,6 +481,23 @@ int pds_neuron_backpropagate_error(PdsNeuron *Neuron);
 int pds_neuron_update_weight(PdsNeuron *Neuron, PdsSnReal Alpha);
 
 
+/** \fn int pds_neuron_update_u_and_weight(PdsNeuron *Neuron, PdsSnReal Alpha)
+ *  \brief Actualiza los pesos W[i] de la neurona (using the Delta rule).
+ *  \f[ e = r-Y\f]
+ *  \f[ \triangle W[i]= \alpha func'\left(\theta\right) X[i] e\f]
+ *  \f[ \triangle U= -\alpha func'\left(\theta\right) e\f]
+ *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
+ *  "Y" salida de la neurona Neuron :Neuron->Y[0].<br>
+ *  "func" es la función de activación da neurona Neuron.<br>
+ *  "X" Vector con los valores de todas las entradas de la neurona.<br>
+ *  \param[in,out] Neuron La neurona a actualizar los pesos.
+ *  \param[in] Alpha Factor de aprendizaje de los pesos.
+ *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
+ *  \ingroup PdsNeuronGroup
+ */
+int pds_neuron_update_u_and_weight(PdsNeuron *Neuron, PdsSnReal Alpha);
+
+
 /** \fn int pds_neuron_get_xtx(PdsNeuron *Neuron,PdsSnReal *XtX)
  *  \brief Devuelve la suma cuadrática de los valores de entrada de la neurona.
  *  \f[ X^T X=\sum^{Nel-1}_{i=0} X[i]^2 \f].
@@ -503,10 +509,11 @@ int pds_neuron_update_weight(PdsNeuron *Neuron, PdsSnReal Alpha);
 int pds_neuron_get_xtx(PdsNeuron *Neuron,PdsSnReal *XtX);
 
 
-/** \fn int pds_neuron_update_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha)
+/** \fn int pds_neuron_update_u_and_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha)
  *  \brief Actualiza los pesos W[i] de la neurona (using the Delta rule).
  *  \f[ e = r-Y\f]
- *  \f[ \triangle W[i]= \alpha \frac{func'\left(\frac{\theta}{\sigma}\right)}{\sigma} \frac{X[i]}{X^TX} e \f]
+ *  \f[ \triangle W[i]= \alpha func'\left(\theta\right) \frac{X[i]}{X^TX+1} e \f]
+ *  \f[ \triangle U= -\alpha func'\left(\theta\right) \frac{1}{X^TX+1} e \f]
  *  "e" es el error de la salida de la neurona Neuron :Neuron->Y[1].<br>
  *  "Y" salida de la neurona Neuron :Neuron->Y[0].<br>
  *  "func" es la función de activación da neurona Neuron.<br>
@@ -516,7 +523,7 @@ int pds_neuron_get_xtx(PdsNeuron *Neuron,PdsSnReal *XtX);
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNeuronGroup
  */
-int pds_neuron_update_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha);
+int pds_neuron_update_u_and_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha);
 
 //@}
 
@@ -527,7 +534,7 @@ int pds_neuron_update_weight_normalized(PdsNeuron *Neuron, PdsSnReal Alpha);
  */
 
 /** \fn int pds_neuron_fprintf(const PdsNeuron *Neuron, FILE *fd)
- *  \brief Guarda en un archivo de texto los pesos {W[i]} y  {U, Sigma}.
+ *  \brief Guarda en un archivo de texto los pesos {W[i]} y  {U}.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
  *  \param[in] Neuron La neurona a leer.
  *  \param[in,out] fd Manejador del fichero a escribir.
@@ -538,7 +545,7 @@ int pds_neuron_fprintf(const PdsNeuron *Neuron, FILE *fd);
 
 
 /** \fn int pds_neuron_fscanf(PdsNeuron *Neuron, FILE *fd)
- *  \brief Lee de un archivo de texto los pesos {W[i]} y  {U, Sigma}.
+ *  \brief Lee de un archivo de texto los pesos {W[i]} y  {U}.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
  *  \param[out] Neuron La neurona a escribir.
  *  \param[in,out] fd Manejador del fichero a leer.
@@ -549,7 +556,7 @@ int pds_neuron_fscanf(PdsNeuron *Neuron, FILE *fd);
 
 
 /** \fn int pds_neuron_fwrite(const PdsNeuron *Neuron, FILE *fd)
- *  \brief Guarda en un archivo binario los pesos W[i], el valor de U y Sigma.
+ *  \brief Guarda en un archivo binario los pesos W[i], el valor de U.
  *  \param[in] Neuron La neurona a leer.
  *  \param[in,out] fd Manejador del fichero binario a escribir.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL o fd==NULL). 
@@ -559,7 +566,7 @@ int pds_neuron_fwrite(const PdsNeuron *Neuron, FILE *fd);
 
 
 /** \fn int pds_neuron_fread(PdsNeuron *Neuron, FILE *fd)
- *  \brief Lee de un archivo binario los pesos W[i], el valor de U y Sigma.
+ *  \brief Lee de un archivo binario los pesos W[i], el valor de U.
  *  \param[out] Neuron La neurona a escribir.
  *  \param[in,out] fd Manejador del fichero binario a leer.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL o fd==NULL). 
