@@ -73,6 +73,12 @@ typedef struct
 }PdsNInput;
 
 
+/** @name pds_ninput_<new>
+ *  Creando nuevas ninput
+ *
+ * @{
+ */
+
 
 /** \fn PdsNInput *pds_ninput_new(void)
  *  \brief Crea una neurona de tipo PdsNInput e inicia con cero todos los elementos.
@@ -81,25 +87,13 @@ typedef struct
  */
 PdsNInput *pds_ninput_new(void);
 
+//@}
 
-/** \fn int pds_ninput_get_input(const PdsNInput *NInput,PdsSnReal *m)
- *  \brief Devuelve el valor de la entrada  de la neurona NInput.
- *  \param[in] NInput La neurona en consulta.
- *  \param[out] m Donde se cargará el valor de la entrada.
- *  \return TRUE si todo fue bien o FALSE si no (ej: NInput==NULL). 
- *  \ingroup PdsNInputGroup
+/** @name pds_ninput_<get_set>
+ *  get set.
+ *
+ * @{
  */
-int pds_ninput_get_input(const PdsNInput *NInput,PdsSnReal *m);
-
-
-/** \fn int pds_ninput_get_output(const PdsNInput *NInput,PdsSnReal *m)
- *  \brief Devuelve el valor de la salida Y de la neurona NInput.
- *  \param[in] NInput La neurona en consulta.
- *  \param[out] m Donde se cargará el valor de la salida Y.
- *  \return TRUE si todo fue bien o FALSE si no (ej: NInput==NULL). 
- *  \ingroup PdsNInputGroup
- */
-int pds_ninput_get_output(const PdsNInput *NInput,PdsSnReal *m);
 
 
 /** \fn int pds_ninput_set_input(PdsNInput *NInput,PdsSnReal m)
@@ -111,6 +105,13 @@ int pds_ninput_get_output(const PdsNInput *NInput,PdsSnReal *m);
  */
 int pds_ninput_set_input(PdsNInput *NInput,PdsSnReal m);
 
+//@}
+
+/** @name pds_ninput_<free>
+ *  Limpiando memoria.
+ *
+ * @{
+ */
 
 /** \fn void pds_ninput_free(PdsNInput *NInput)
  *  \brief Libera una neurona de tipo puntero PdsNInput.
@@ -129,6 +130,9 @@ void pds_ninput_free(PdsNInput *NInput);
  */
 void pds_ninput_destroy(PdsNInput **NInput);
 
+//@}
+
+
 /**
  * @}
  */
